﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2018 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;
using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Problems.DataAnalysis {
  [Item("Clustering Transformation Model", "A clustering model that was transformed back to match the original variables after the training was performed on transformed variables.")]
  [StorableClass]
  public class ClusteringTransformationModel : DataAnalysisTransformationModel, IClusteringTransformationModel {

    public new IClusteringModel OriginalModel {
      get { return (IClusteringModel)base.OriginalModel; }
    }

    #region Constructor, Cloning & Persistence
    public ClusteringTransformationModel(IClusteringModel originalModel, IEnumerable<IDataAnalysisTransformation> transformations)
      : base(originalModel, transformations) {
    }

    protected ClusteringTransformationModel(ClusteringTransformationModel original, Cloner cloner)
      : base(original, cloner) {
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new ClusteringTransformationModel(this, cloner);
    }

    [StorableConstructor]
    protected ClusteringTransformationModel(bool deserializing)
      : base(deserializing) { }
    #endregion

    public IEnumerable<int> GetClusterValues(IDataset dataset, IEnumerable<int> rows) {
      return OriginalModel.GetClusterValues(Transform(dataset, InputTransformations), rows);
    }
  }
}